@@ -1,10 +1,10 @@
 /*
  * vim: softtabstop=4 shiftwidth=4 cindent foldmethod=marker expandtab
  *
- * $LastChangedDate: 2011-06-27 13:20:10 -0600 (Mon, 27 Jun 2011) $
- * $Revision: 1139 $
+ * $LastChangedDate: 2012-06-16 13:10:54 -0600 (Sat, 16 Jun 2012) $
+ * $Revision: 1176 $
  * $LastChangedBy: econnell $
- * $URL: http://svn.mangler.org/mangler/trunk/src/manglerg15.cpp $
+ * $URL: http://svn.mangler.org/mangler/tags/1.2.4/src/manglerg15.cpp $
  *
  * Copyright 2009-2011 Eric Connell
  *
@@ -64,6 +64,9 @@ ManglerG15::addevent(Glib::ustring text) {
 void
 ManglerG15::update(Glib::ustring server, Glib::ustring lastXmit,  Glib::ustring serverJoin,  Glib::ustring chanJoin,  Glib::ustring ping) {
     char buf[130];
+    if (fd <= 0) {
+        return;
+    }
     if (server != "") {
         this->server = server;
     }
